@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -20,8 +19,8 @@
  *
  ****************************************************************************/
 
-#ifndef _GRAIL_GESTURE_BUFFER_H
-#define _GRAIL_GESTURE_BUFFER_H
+#ifndef GRAIL_GESTURE_BUFFER_H
+#define GRAIL_GESTURE_BUFFER_H
 
 #include "grail-impl.h"
 
