@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -38,20 +37,16 @@ static void set_props(const struct gesture_inserter *gin,
 		      const struct utouch_frame *frame)
 {
 	if (m->single) {
-		s->prop[GRAIL_PROP_DRAG_DX] =
-			gin->scale_x * m->fm[FM_X].raw_delta;
-		s->prop[GRAIL_PROP_DRAG_DY] =
-			gin->scale_y * m->fm[FM_Y].raw_delta;
+		s->prop[GRAIL_PROP_DRAG_DX] = m->fm[FM_X].raw_delta;
+		s->prop[GRAIL_PROP_DRAG_DY] = m->fm[FM_Y].raw_delta;
 	} else {
-		s->prop[GRAIL_PROP_DRAG_DX] =
-			gin->scale_x * m->fm[FM_X].action_delta;
-		s->prop[GRAIL_PROP_DRAG_DY] =
-			gin->scale_y * m->fm[FM_Y].action_delta;
+		s->prop[GRAIL_PROP_DRAG_DX] = m->fm[FM_X].action_delta;
+		s->prop[GRAIL_PROP_DRAG_DY] = m->fm[FM_Y].action_delta;
 	}
-	s->prop[GRAIL_PROP_DRAG_VX] = gin->scale_x * m->fm[FM_X].velocity;
-	s->prop[GRAIL_PROP_DRAG_VY] = gin->scale_y * m->fm[FM_Y].velocity;
-	s->prop[GRAIL_PROP_DRAG_X] = gin_prop_x(gin, m->fm[FM_X].value);
-	s->prop[GRAIL_PROP_DRAG_Y] = gin_prop_y(gin, m->fm[FM_Y].value);
+	s->prop[GRAIL_PROP_DRAG_VX] = m->fm[FM_X].velocity;
+	s->prop[GRAIL_PROP_DRAG_VY] = m->fm[FM_Y].velocity;
+	s->prop[GRAIL_PROP_DRAG_X] = m->fm[FM_X].value;
+	s->prop[GRAIL_PROP_DRAG_Y] = m->fm[FM_Y].value;
 	s->nprop = 6;
 	s->nprop += gin_add_contact_props(gin, s->prop + s->nprop, frame);
 }
@@ -74,10 +69,8 @@ int gru_drag(struct grail *ge,
 	}
 	if ((move->timeout & fm_mask) == fm_mask) {
 		if (state->active) {
-			gin_gid_discard(ge, state->gid);
-			state->active = 0;
+			gin_gid_timeout(ge, state->gid);
 		}
-		return 0;
 	}
 	if (!state->active) {
 		int type = getype[move->ntouch];
@@ -88,7 +81,7 @@ int gru_drag(struct grail *ge,
 	}
 	if (!(move->tickle & mask))
 		return 0;
-	if (!move->single && !(move->active & fm_mask))
+	if (!(move->active & fm_mask))
 		return 0;
 	set_props(ge->gin, state, move, frame);
 	gru_event(ge, state->gid, move, state->prop, state->nprop);
@@ -111,10 +104,8 @@ int gru_windrag(struct grail *ge,
 	}
 	if ((move->timeout & fm_mask) == fm_mask) {
 		if (state->active) {
-			gin_gid_discard(ge, state->gid);
-			state->active = 0;
+			gin_gid_timeout(ge, state->gid);
 		}
-		return 0;
 	}
 	if (!state->active) {
 		if (move->ntouch == 4) {
@@ -135,7 +126,7 @@ int gru_windrag(struct grail *ge,
 	}
 	if (!(move->tickle & mask))
 		return 0;
-	if (!move->single && !(move->active & fm_mask))
+	if (!(move->active & fm_mask))
 		return 0;
 	set_props(ge->gin, state, move, frame);
 	gru_event(ge, state->gid, move, state->prop, state->nprop);
