@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -40,10 +39,12 @@ static void set_props(const struct gesture_inserter *gin,
 		      const struct move_model *m,
 		      const struct utouch_frame *frame)
 {
-	s->prop[GRAIL_PROP_PINCH_DR] = gin->scale_r * m->fm[FM_R].action_delta;
-	s->prop[GRAIL_PROP_PINCH_VR] = gin->scale_r * m->fm[FM_R].velocity;
-	s->prop[GRAIL_PROP_PINCH_R] = gin->scale_r * m->fm[FM_R].value;
-	s->nprop = 3;
+	s->prop[GRAIL_PROP_PINCH_DR] = m->fm[FM_R].action_delta;
+	s->prop[GRAIL_PROP_PINCH_VR] = m->fm[FM_R].velocity;
+	s->prop[GRAIL_PROP_PINCH_R] = m->fm[FM_R].value;
+	s->prop[GRAIL_PROP_PINCH_X] = m->fm[FM_X].value;
+	s->prop[GRAIL_PROP_PINCH_Y] = m->fm[FM_Y].value;
+	s->nprop = 5;
 	s->nprop += gin_add_contact_props(gin, s->prop + s->nprop, frame);
 }
 
@@ -64,10 +65,8 @@ int gru_pinch(struct grail *ge,
 	}
 	if ((move->timeout & fm_mask) == fm_mask) {
 		if (state->active) {
-			gin_gid_discard(ge, state->gid);
-			state->active = 0;
+			gin_gid_timeout(ge, state->gid);
 		}
-		return 0;
 	}
 	if (!(move->tickle & mask))
 		return 0;
@@ -102,10 +101,8 @@ int gru_winpinch(struct grail *ge,
 	}
 	if ((move->timeout & fm_mask) == fm_mask) {
 		if (state->active) {
-			gin_gid_discard(ge, state->gid);
-			state->active = 0;
+			gin_gid_timeout(ge, state->gid);
 		}
-		return 0;
 	}
 	if (!(move->tickle & mask))
 		return 0;
