@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -42,7 +41,9 @@ static void set_props(const struct gesture_inserter *gin,
 	s->prop[GRAIL_PROP_ROTATE_DA] = m->fm[FM_A].action_delta;
 	s->prop[GRAIL_PROP_ROTATE_VA] = m->fm[FM_A].velocity;
 	s->prop[GRAIL_PROP_ROTATE_A] = m->fm[FM_A].value;
-	s->nprop = 3;
+	s->prop[GRAIL_PROP_ROTATE_X] = m->fm[FM_X].value;
+	s->prop[GRAIL_PROP_ROTATE_Y] = m->fm[FM_Y].value;
+	s->nprop = 5;
 	s->nprop += gin_add_contact_props(gin, s->prop + s->nprop, frame);
 }
 
@@ -63,10 +64,8 @@ int gru_rotate(struct grail *ge,
 	}
 	if ((move->timeout & fm_mask) == fm_mask) {
 		if (state->active) {
-			gin_gid_discard(ge, state->gid);
-			state->active = 0;
+			gin_gid_timeout(ge, state->gid);
 		}
-		return 0;
 	}
 	if (!(move->tickle & mask))
 		return 0;
@@ -101,10 +100,8 @@ int gru_winrotate(struct grail *ge,
 	}
 	if ((move->timeout & fm_mask) == fm_mask) {
 		if (state->active) {
-			gin_gid_discard(ge, state->gid);
-			state->active = 0;
+			gin_gid_timeout(ge, state->gid);
 		}
-		return 0;
 	}
 	if (!(move->tickle & mask))
 		return 0;
