@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -30,8 +29,8 @@ static void set_props(const struct gesture_inserter *gin,
 		      const struct utouch_frame *frame)
 {
 	s->prop[GRAIL_PROP_TAP_DT] = m->time - s->start;
-	s->prop[GRAIL_PROP_TAP_X] = gin_prop_x(gin, m->fm[FM_X].value);
-	s->prop[GRAIL_PROP_TAP_Y] = gin_prop_y(gin, m->fm[FM_Y].value);
+	s->prop[GRAIL_PROP_TAP_X] = m->fm[FM_X].value;
+	s->prop[GRAIL_PROP_TAP_Y] = m->fm[FM_Y].value;
 	s->nprop = 3;
 	s->nprop += gin_add_contact_props(gin, s->prop + s->nprop, frame);
 }
@@ -89,7 +88,7 @@ int gru_tapping(struct grail *ge,
 	}
 	if (!move->ntouch)
 		return 0;
-	set_props(ge->gin, state, move, frame);
+	state->prop[GRAIL_PROP_TAP_DT] = move->time - state->start;
 	if ((move->active & fm_mask) ||
 	    move->time - state->start > move->fm[FM_X].bar_ms) {
 		gin_gid_discard(ge, state->gid);
