@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -62,15 +61,15 @@ int gin_add_contact_props(const struct gesture_inserter *gin,
 	if (ntouch > 5)
 		ntouch = 5;
 	compute_bbox(&min, &max, frame);
-	prop[n++] = gin_prop_x(gin, min.x);
-	prop[n++] = gin_prop_y(gin, min.y);
-	prop[n++] = gin_prop_x(gin, max.x);
-	prop[n++] = gin_prop_y(gin, max.y);
+	prop[n++] = min.x;
+	prop[n++] = min.y;
+	prop[n++] = max.x;
+	prop[n++] = max.y;
 	for (i = 0; i < ntouch; i++) {
 		const struct utouch_contact *ct = frame->active[i];
 		prop[n++] = ct->id;
-		prop[n++] = gin_prop_x(gin, ct->x);
-		prop[n++] = gin_prop_y(gin, ct->y);
+		prop[n++] = ct->x;
+		prop[n++] = ct->y;
 	}
 	return n;
 }
@@ -86,8 +85,8 @@ int gin_get_clients(struct grail *ge,
 	if (!ge->get_clients)
 		return 0;
 	grail_mask_foreach(i, span, bspan) {
-		pos[npos].x = gin_prop_x(ge->gin, frame->slots[i]->x);
-		pos[npos].y = gin_prop_y(ge->gin, frame->slots[i]->y);
+		pos[npos].x = frame->slots[i]->x;
+		pos[npos].y = frame->slots[i]->y;
 		npos++;
 	}
 	return ge->get_clients(ge, info, maxinfo, pos, npos, types, btypes);
@@ -109,36 +108,11 @@ void gin_send_event(struct grail *ge, struct slot_state *s,
 	gev.ntouch = ev->ntouch;
 	gev.nprop = ev->nprop;
 	gev.time = ev->time;
-	gev.pos.x = gin_prop_x(gin, ev->pos.x);
-	gev.pos.y = gin_prop_y(gin, ev->pos.y);
+	gev.pos.x = ev->pos.x;
+	gev.pos.y = ev->pos.y;
 	memcpy(gev.prop, ev->prop, ev->nprop * sizeof(grail_prop_t));
 	for (i = 0; i < s->nclient; i++) {
 		gev.client_id = s->client_id[i];
 		grailbuf_put(&impl->gbuf, &gev);
 	}
 }
-
-int grail_get_contacts(const struct grail *ge,
-		       struct grail_contact *touch, int max_touch)
-{
-	const struct gesture_inserter *gin = ge->gin;
-	const struct utouch_frame *frame = ge->impl->frame;
-	int i;
-	if (frame->num_active < max_touch)
-		max_touch = frame->num_active;
-	for (i = 0; i < max_touch; i++) {
-		struct grail_contact *t = &touch[i];
-		const struct utouch_contact *ct = frame->active[i];
-		t->id = ct->id;
-		t->tool_type = ct->tool_type;
-		t->pos.x = gin_prop_x(gin, ct->x);
-		t->pos.y = gin_prop_y(gin, ct->y);
-		t->touch_major = gin->scale_r * ct->touch_major;
-		t->touch_minor = gin->scale_r * ct->touch_minor;
-		t->width_major = gin->scale_r * ct->width_major;
-		t->width_minor = gin->scale_r * ct->width_minor;
-		t->angle = ct->orientation;
-		t->pressure = ct->pressure;
-	}
-	return max_touch;
-}
