@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,11 +23,15 @@
 #include "grail-impl.h"
 #include <math.h>
 
-static const float FM_SN[DIM_FM] = { 1000, 1000, 1000, 1000 };
-static const float FM_BAR[DIM_FM] = { 50, 50, 50, 50 };
+/* Units of mm or radians */
+static const float FM_SN[DIM_FM] = { 0.13, 0.13, 0.26, 2 * M_PI / 1000 };
+static const float FM_BAR[DIM_FM] = { 2.6, 2.6, 5.2, 2 * M_PI / 50 };
+
+/* Units of ms */
 static const grail_time_t FM_HOLD_MS[DIM_FM] = { 60, 60, 60, 60 };
 static const grail_time_t FM_BAR_MS[DIM_FM] = { 300, 300, 500, 500 };
 static const grail_time_t SAMPLE_MS = 10;
+
 static const float EPS = 1e-3;
 
 static void compute_position(float *x, float *y,
@@ -87,18 +90,6 @@ static float compute_rotation(float x, float y, float r,
 	return da;
 }
 
-/* Response-augmented EWMA filter, courtesy of Vojtech Pavlik */
-static float move_filter(const struct filter_model *m, float val)
-{
-	if (val > m->value - m->fuzz / 2 && val < m->value + m->fuzz / 2)
-		return m->value;
-	if (val > m->value - m->fuzz && val < m->value + m->fuzz)
-		return (m->value * 3 + val) / 4;
-	if (val > m->value - m->fuzz * 2 && val < m->value + m->fuzz * 2)
-		return (m->value + val) / 2;
-	return val;
-}
-
 static void move_reset(struct move_model *m, int i, float x, grail_time_t t)
 {
 	struct filter_model *fm = &m->fm[i];
@@ -133,15 +124,14 @@ static void move_update(struct move_model *m, int i, float x, grail_time_t t)
 		m->tickle &= ~(1 << i);
 	if (m->active & (1 << i))
 		return;
-	fm->action_delta = x - fm->original;
-	if (t - fm->original_ms > fm->hold_ms &&
-	    fabs(fm->action_delta) > fm->bar) {
-		m->active |= (1 << i);
+	fm->action_delta = 0;
+	if (fabs(x - fm->original) > fm->bar) {
+		if (t - fm->original_ms > fm->hold_ms) {
+			m->active |= (1 << i);
+			fm->action_delta = x - fm->original;
+		}
 	} else if (t - fm->original_ms > fm->bar_ms) {
-		m->active |= (1 << i);
 		m->timeout |= (1 << i);
-	} else {
-		fm->action_delta = 0;
 	}
 }
 
@@ -150,15 +140,20 @@ void gru_init_motion(struct grail *ge)
 	struct utouch_surface *s = utouch_frame_get_surface(ge->impl->fh);
 	struct gesture_recognizer *gru = ge->gru;
 	struct move_model *m = &gru->move;
-	float D[DIM_FM];
+	float U[DIM_FM]; /* Device unit dimensions */
+	float P[DIM_FM]; /* Device physical dimensions */
 	int i;
-	D[FM_X] = s->max_x - s->min_x;
-	D[FM_Y] = s->max_y - s->min_y;
-	D[FM_R] = sqrt(D[FM_X] * D[FM_X] + D[FM_Y] * D[FM_Y]);
-	D[FM_A] = 2 * M_PI;
+	U[FM_X] = s->mapped_max_x - s->mapped_min_x;
+	U[FM_Y] = s->mapped_max_y - s->mapped_min_y;
+	U[FM_R] = sqrt(U[FM_X] * U[FM_X] + U[FM_Y] * U[FM_Y]);
+	U[FM_A] = 2 * M_PI;
+	P[FM_X] = s->phys_width;
+	P[FM_Y] = s->phys_height;
+	P[FM_R] = sqrt(P[FM_X] * P[FM_X] + P[FM_Y] * P[FM_Y]);
+	P[FM_A] = 2 * M_PI;
 	for (i = 0; i < DIM_FM; i++) {
-		m->fm[i].fuzz = D[i] / FM_SN[i];
-		m->fm[i].bar = D[i] / FM_BAR[i];
+		m->fm[i].fuzz = U[i] * FM_SN[i] / P[i];
+		m->fm[i].bar = U[i] * FM_BAR[i] / P[i];
 		m->fm[i].hold_ms = FM_HOLD_MS[i];
 		m->fm[i].bar_ms = FM_BAR_MS[i];
 	}
@@ -167,6 +162,7 @@ void gru_init_motion(struct grail *ge)
 void gru_motion(struct grail *ge,
 		const struct utouch_frame *frame)
 {
+	const struct utouch_surface *s = utouch_frame_get_surface(ge->impl->fh);
 	struct gesture_recognizer *gru = ge->gru;
 	struct move_model *m = &gru->move;
 	grail_time_t t = frame->time;
@@ -192,13 +188,10 @@ void gru_motion(struct grail *ge,
 		m->single = 1;
 		m->multi = 0;
 	} else {
-		x = move_filter(&m->fm[FM_X], x);
-		y = move_filter(&m->fm[FM_Y], y);
 		r = compute_radius(x, y, frame);
-		r = move_filter(&m->fm[FM_R], r);
 		a = m->fm[FM_A].value;
-		a += compute_rotation(x, y, r, frame);
-		a = move_filter(&m->fm[FM_A], a);
+		if (!s->is_semi_mt)
+			a += compute_rotation(x, y, r, frame);
 		move_update(m, FM_X, x, t);
 		move_update(m, FM_Y, y, t);
 		move_update(m, FM_R, r, t);
