@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -20,8 +19,8 @@
  *
  ****************************************************************************/
 
-#ifndef _GRAIL_GESTURES_H
-#define _GRAIL_GESTURES_H
+#ifndef GRAIL_GESTURES_H
+#define GRAIL_GESTURES_H
 
 #include "grail-inserter.h"
 
@@ -77,6 +76,8 @@ struct combo_model {
 	grail_prop_t prop[DIM_GRAIL_PROP];
 };
 
+int gru_touch(struct grail *ge,
+	      const struct utouch_frame *frame);
 int gru_drag(struct grail *ge,
 	     const struct utouch_frame *frame);
 int gru_pinch(struct grail *ge,
@@ -90,6 +91,8 @@ static inline int out_of_bounds(const struct combo_model *s,
 	return m->ntouch < s->mintouch || m->ntouch > s->maxtouch;
 }
 
+int gru_wintouch(struct grail *ge,
+		 const struct utouch_frame *frame);
 int gru_windrag(struct grail *ge,
 		const struct utouch_frame *frame);
 int gru_winpinch(struct grail *ge,
