@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -20,6 +19,7 @@
  *
  ****************************************************************************/
 
+#include "grail-gestures.h"
 #include "grail-inserter.h"
 #include "grail-impl.h"
 #include <malloc.h>
@@ -38,6 +38,18 @@ static int find_gslot(const struct gesture_inserter *gin, int gid)
 	return -1;
 }
 
+static int mask_overlap(const grail_mask_t *a, const grail_mask_t *b,
+			int bytes)
+{
+	int i;
+
+	for (i = 0; i < bytes; i++)
+		if (a[i] & b[i])
+			return 1;
+
+	return 0;
+}
+
 // todo: spanning tree for multi-user case
 static void setup_new_gestures(struct grail *ge,
 			       const struct utouch_frame *frame)
@@ -92,11 +104,6 @@ int gin_init(struct grail *ge)
 		return -ENOMEM;
 	for (i = 0; i < DIM_INSTANCE; i++)
 		grail_mask_set(gin->unused, i);
-	gin->scale_x = 1;
-	gin->scale_y = 1;
-	gin->scale_r = 1;
-	gin->trans_x = 1;
-	gin->trans_y = 1;
 	ge->gin = gin;
 	return 0;
 }
@@ -119,38 +126,56 @@ void gin_frame_begin(struct grail *ge, const struct utouch_frame *frame)
 void gin_frame_end(struct grail *ge, const struct utouch_frame *frame)
 {
 	struct gesture_inserter *gin = ge->gin;
-	int i, hold = 0, discard = 0;
+	grail_mask_t keep[DIM_TOUCH_BYTES];
+	int i, hold[2] = { 0, 0 }, discard[2] = { 0, 0 };
 
+	memset(keep, 0, sizeof(keep));
 	setup_new_gestures(ge, frame);
 
 	grail_mask_foreach(i, gin->used, sizeof(gin->used)) {
 		struct slot_state *s = &gin->state[i];
 		if (!s->nclient)
 			continue;
-		if (s->priority > hold)
-			hold = s->priority;
+		if (s->priority > hold[s->slice])
+			hold[s->slice] = s->priority;
 		if (s->status != GRAIL_STATUS_UPDATE)
 			continue;
-		if (s->priority > discard)
-			discard = s->priority;
+		if (s->priority > discard[s->slice])
+			discard[s->slice] = s->priority;
 	}
 
 	grail_mask_foreach(i, gin->used, sizeof(gin->used)) {
 		struct slot_state *s = &gin->state[i];
-		if (!s->nclient || s->priority < discard)
+		if (!s->nclient || s->priority < discard[s->slice] && !s->sent)
 			gin_gid_discard(ge, s->id);
 	}
 
+	grail_mask_foreach(i, gin->used, sizeof(gin->used)) {
+		struct slot_state *s = &gin->state[i];
+		if (s->slice == 1)
+			grail_mask_set_mask(keep, s->span, sizeof(keep));
+	}
+
+	grail_mask_foreach(i, gin->used, sizeof(gin->used)) {
+		struct slot_state *s = &gin->state[i];
+		if (!s->timeout)
+			continue;
+		if (mask_overlap(keep, s->span, sizeof(keep)))
+			continue;
+		gin_gid_discard(ge, s->id);
+	}
+
 	grail_mask_foreach(i, gin->used, sizeof(gin->used)) {
 		struct slot_state *s = &gin->state[i];
 		struct gesture_event ev;
 		grail_mask_set(gin->types, s->type);
-		if (s->priority < hold)
+		if (s->priority < hold[s->slice] && !s->sent)
 			continue;
 		while (!gebuf_empty(&s->buf)) {
 			gebuf_get(&s->buf, &ev);
 			gin_send_event(ge, s, &ev, frame);
 		}
+		s->sent = 1;
 	}
 
 	grail_mask_foreach(i, gin->used, sizeof(gin->used)) {
@@ -171,7 +196,15 @@ int gin_gid_begin(struct grail *ge, int type, int priority,
 		return -1;
 	s = &gin->state[i];
 	s->type = type;
-	s->priority = priority;
+	if (priority < 0) {
+		s->priority = -priority;
+		s->slice = 1;
+	} else {
+		s->priority = priority;
+		s->slice = 0;
+	}
+	s->timeout = 0;
+	s->sent = 0;
 	s->id = gin->gestureid++ & MAX_GESTURE_ID;
 	s->status = GRAIL_STATUS_BEGIN;
 	s->nclient = 0;
@@ -198,6 +231,13 @@ void gin_gid_discard(struct grail *ge, int gid)
 	grail_mask_set(gin->unused, i);
 }
 
+void gin_gid_timeout(struct grail *ge, int gid)
+{
+	int i = find_gslot(ge->gin, gid);
+	if (i >= 0)
+		ge->gin->state[i].timeout = 1;
+}
+
 void gin_gid_event(struct grail *ge, int gid,
 		   float x, float y, int ntouch,
 		   const grail_prop_t *prop, int nprop,
@@ -248,22 +288,17 @@ void gin_gid_end(struct grail *ge, int gid,
 	s->status = GRAIL_STATUS_END;
 }
 
-void grail_set_bbox(struct grail *ge,
-		    const struct grail_coord *tmin,
-		    const struct grail_coord *tmax)
+void GRAIL_PUBLIC grail_set_bbox(struct grail *ge,
+				 const struct grail_coord *tmin,
+				 const struct grail_coord *tmax)
 {
 	struct utouch_surface *s = utouch_frame_get_surface(ge->impl->fh);
-	struct gesture_inserter *gin = ge->gin;
-	double tx, ty, dx, dy, sx, sy;
-	tx = tmax->x - tmin->x;
-	ty = tmax->y - tmin->y;
-	dx = s->max_x - s->min_x;
-	dy = s->max_y - s->min_y;
-	sx = tx / dx;
-	sy = ty / dy;
-	gin->scale_x = sx;
-	gin->scale_y = sy;
-	gin->scale_r = sqrt((tx * tx + ty * ty) / (dx * dx + dy * dy));
-	gin->trans_x = tmin->x - s->min_x * sx;
-	gin->trans_y = tmin->y - s->min_y * sy;
+
+	s->mapped_min_x = tmin->x;
+	s->mapped_min_y = tmin->y;
+	s->mapped_max_x = tmax->x;
+	s->mapped_max_y = tmax->y;
+
+	if (ge->gru)
+		gru_init_motion(ge);
 }
