@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -20,8 +19,8 @@
  *
  ****************************************************************************/
 
-#ifndef _GRAIL_INSERTER_H
-#define _GRAIL_INSERTER_H
+#ifndef GRAIL_INSERTER_H
+#define GRAIL_INSERTER_H
 
 #include "grail-impl.h"
 #include "gebuf.h"
@@ -37,6 +36,9 @@
 struct slot_state {
 	int type;
 	int priority;
+	int slice;
+	int timeout;
+	int sent;
 	int id;
 	int status;
 	int nclient;
@@ -55,20 +57,8 @@ struct gesture_inserter {
 	int gestureid;
 	int grab_active;
 	int grab_client;
-	float scale_x, scale_y, scale_r;
-	float trans_x, trans_y;
 };
 
-static inline float gin_prop_x(const struct gesture_inserter *gin, float x)
-{
-	return gin->scale_x * x + gin->trans_x;
-}
-
-static inline float gin_prop_y(const struct gesture_inserter *gin, float y)
-{
-	return gin->scale_y * y + gin->trans_y;
-}
-
 int gin_add_contact_props(const struct gesture_inserter *gin,
 			  grail_prop_t *prop, const struct utouch_frame *frame);
 
@@ -90,6 +80,7 @@ void gin_frame_end(struct grail *ge, const struct utouch_frame *frame);
 int gin_gid_begin(struct grail *ge, int type, int priority,
 		  const struct utouch_frame *frame);
 void gin_gid_discard(struct grail *ge, int gid);
+void gin_gid_timeout(struct grail *ge, int gid);
 
 void gin_gid_event(struct grail *ge, int gid,
 		   float x, float y, int ntouch,
