@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -47,9 +46,11 @@ void gru_recognize(struct grail *ge, const struct utouch_frame *frame)
 	if (!ge->gin || !ge->gru)
 		return;
 	gru_motion(ge, frame);
+	gru_touch(ge, frame);
 	gru_drag(ge, frame);
 	gru_pinch(ge, frame);
 	gru_rotate(ge, frame);
+	gru_wintouch(ge, frame);
 	gru_windrag(ge, frame);
 	gru_winpinch(ge, frame);
 	gru_winrotate(ge, frame);
