@@ -2,8 +2,7 @@
  *
  * grail - Gesture Recognition And Instantiation Library
  *
- * Copyright (C) 2010 Canonical Ltd.
- * Copyright (C) 2010 Henrik Rydberg <rydberg@bitmath.org>
+ * Copyright (C) 2010-2011 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -20,16 +19,18 @@
  *
  ****************************************************************************/
 
-#ifndef _GRAIL_RECOGNIZER_H
-#define _GRAIL_RECOGNIZER_H
+#ifndef GRAIL_RECOGNIZER_H
+#define GRAIL_RECOGNIZER_H
 
 #include "grail-gestures.h"
 
 struct gesture_recognizer {
 	struct move_model move;
+	struct combo_model touch;
 	struct combo_model drag;
 	struct combo_model pinch;
 	struct combo_model rotate;
+	struct combo_model wintouch;
 	struct combo_model windrag;
 	struct combo_model winpinch;
 	struct combo_model winrotate;
